==> phpunit_9.6.7.orig.tar.xz: phpunit-9.6.7/.github/ISSUE_TEMPLATE/5_COMPATIBILITY_PHPUNIT_9.md <==
---
name: ⚠️ PHP Compatibility Issue in PHPUnit 9
about: A change in a new version of PHP requires adaption in PHPUnit 9?
labels: type/change-in-php-requires-adaptation, version/9
---

<!--
- Please do not report an issue for a version of PHPUnit that is no longer supported. A list of currently supported versions of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are using a version of PHP that is not supported by the version of PHPUnit you are using. A list that shows which version of PHP is supported by which version of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are not using PHPUnit directly, but rather a wrapper around it such as Symfony's PHPUnit Bridge
- Please fill in this template according to your issue.
- Please keep the table shown below at the top of your issue.
- Please include the output of "composer info | sort" if you installed PHPUnit using Composer.
- Please post code as text (using proper markup). Do not post screenshots of code.
- Visit https://phpunit.de/support.html if you are looking for support.
- Please remove this comment before submitting your issue.
-->

| Q                   | A
| --------------------| ---------------
| PHPUnit version     | x.y.z
| PHP version         | x.y.z
| Installation Method | Composer / PHAR

#### Summary

<!-- Provide a summary describing the problem you are experiencing. -->

#### Current behavior

<!-- What is the current behavior? -->

#### How to reproduce

<!-- Provide steps to reproduce the issue. -->

#### Expected behavior

<!-- What was the expected (correct) behavior? -->

==> phpunit_9.6.10.orig.tar.xz: phpunit-9.6.10/.github/ISSUE_TEMPLATE/5_COMPATIBILITY_PHPUNIT_9.md <==
---
name: ⚠️ PHP Compatibility Issue in PHPUnit 9
about: A change in a new version of PHP requires adaption in PHPUnit 9?
labels: type/change-in-php-requires-adaptation, version/9
---

<!--
- Please do not report an issue for a version of PHPUnit that is no longer supported. A list of currently supported versions of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are using a version of PHP that is not supported by the version of PHPUnit you are using. A list that shows which version of PHP is supported by which version of PHPUnit is available at https://phpunit.de/supported-versions.html.
- Please do not report an issue if you are not using PHPUnit directly, but rather a third-party wrapper around it.
- Please do not report an issue if you are using a third-party extension such as alternative output printers.
- Please fill in this template according to your issue.
- Please keep the table shown below at the top of your issue.
- Please include the output of "composer info | sort" if you installed PHPUnit using Composer.
- Please post code as text (using proper markup). Do not post screenshots of code.
- Visit https://phpunit.de/support.html if you are looking for support.
- Please remove this comment before submitting your issue.
-->

| Q                   | A
| --------------------| ---------------
| PHPUnit version     | x.y.z
| PHP version         | x.y.z
| Installation Method | Composer / PHAR

#### Summary

<!-- Provide a summary describing the problem you are experiencing. -->

#### Current behavior

<!-- What is the current behavior? -->

#### How to reproduce

<!-- Provide steps to reproduce the issue. -->

#### Expected behavior

<!-- What was the expected (correct) behavior? -->
